@@ -1,7 +1,7 @@
 package Bencher::Scenario::PERLANCARTreeExamples;
 
-our $DATE = '2016-04-12'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,7 +44,7 @@ Bencher::Scenario::PERLANCARTreeExamples - Benchmark PERLANCAR::Tree::Examples
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::PERLANCARTreeExamples (from Perl distribution Bencher-Scenario-PERLANCARTreeExamples), released on 2016-04-12.
+This document describes version 0.03 of Bencher::Scenario::PERLANCARTreeExamples (from Perl distribution Bencher-Scenario-PERLANCARTreeExamples), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -58,11 +58,19 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Created just for testing, while adding feature in C<Bencher> to return result
+size.
+
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<PERLANCAR::Tree::Examples> 1.000.004
+L<PERLANCAR::Tree::Examples> 1.0.6
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -88,36 +96,33 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m PERLANCARTreeExamples >>):
 
- +-------------+----------+-----------+-----------+------------+------------------+---------+---------+
- | arg_backend | arg_size | rate (/s) | time (ms) | vs_slowest | result_size (MB) | errors  | samples |
- +-------------+----------+-----------+-----------+------------+------------------+---------+---------+
- | hash        | medium1  | 13        | 75        | 1          | 8.2              | 0.00013 | 21      |
- | array       | medium1  | 14        | 71        | 1.1        | 3.7              | 9.1e-05 | 20      |
- | hash        | tiny1    | 6.2e+04   | 0.016     | 4.6e+03    | 0.0013           | 6e-08   | 20      |
- | array       | tiny1    | 6.5e+04   | 0.015     | 4.9e+03    | 0.00052          | 2.7e-08 | 20      |
- +-------------+----------+-----------+-----------+------------+------------------+---------+---------+
+ #table1#
+ +-------------+----------+-----------+-----------+------------+-----------+---------+
+ | arg_backend | arg_size | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +-------------+----------+-----------+-----------+------------+-----------+---------+
+ | hash        | medium1  |        11 |    93     |        1   |   0.00042 |      20 |
+ | array       | medium1  |        12 |    86     |        1.1 |   0.00029 |      21 |
+ | hash        | tiny1    |     47000 |     0.021 |     4300   | 5.9e-08   |      21 |
+ | array       | tiny1    |     54000 |     0.018 |     5000   | 5.1e-08   |      22 |
+ +-------------+----------+-----------+-----------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m PERLANCARTreeExamples --module-startup >>):
 
- +---------------------------+-----------+------------------------+------------+---------+---------+
- | participant               | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
- +---------------------------+-----------+------------------------+------------+---------+---------+
- | PERLANCAR::Tree::Examples | 19        | 9.9                    | 1          | 9.3e-05 | 20      |
- | perl -e1 (baseline)       | 9.1       | 0                      | 2.1        | 7.7e-05 | 21      |
- +---------------------------+-----------+------------------------+------------+---------+---------+
-
-=head1 DESCRIPTION
-
-Created just for testing, while adding feature in C<Bencher> to return result
-size.
+ #table2#
+ +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant               | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | PERLANCAR::Tree::Examples | 0.82                         | 4                  | 16             |        36 |                     21 |        1   |   8e-05 |      20 |
+ | perl -e1 (baseline)       | 2.9                          | 6.2                | 20             |        15 |                      0 |        2.4 | 2.8e-05 |      20 |
+ +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -141,7 +146,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
